@@ -5,7 +5,7 @@ var indexSectionsWithContent =
   2: "s",
   3: "_cdghmnopstuv",
   4: "_abcdefghiklmnoprstuvw",
-  5: "_abcdefghilmnoprstuvw",
+  5: "abcdefghilmnoprstuvw",
   6: "s"
 };
 
